OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Impossibile scrivere nella cartella \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella config.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ma, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true.",
    "See %s" : "Vedi %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "L'applicazione %1$s non è presente o ha una versione non compatibile con questo server. Controlla l'elenco delle applicazioni.",
    "Sample configuration detected" : "Configurazione di esempio rilevata",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
    "The page could not be found on the server." : "Impossibile trovare la pagina sul server.",
    "%s email verification" : "Verifica email di %s",
    "Email verification" : "Verifica email",
    "Click the following button to confirm your email." : "Fai clic sul pulsante seguente per confermare la tua email.",
    "Click the following link to confirm your email." : "Fai clic sul collegamento seguente per confermare la tua email.",
    "Confirm your email" : "Conferma la tua email",
    "Other activities" : "Altre attività",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education bundle" : "Pacchetto istruzione",
    "Enterprise bundle" : "Pacchetto Enterprise",
    "Groupware bundle" : "Pacchetto Groupware",
    "Hub bundle" : "Pacchetto Hub",
    "Public sector bundle" : "Pacchetto settore pubblico",
    "Social sharing bundle" : "Pacchetto Social sharing",
    "PHP %s or higher is required." : "Richiesto PHP %s o superiore",
    "PHP with a version lower than %s is required." : "Richiesta una versione di PHP minore di %s.",
    "%sbit or higher PHP required." : "Richiesto PHP %sbit o superiore.",
    "The following architectures are supported: %s" : "Sono supportate le seguenti architetture: %s",
    "The following databases are supported: %s" : "I seguenti database sono supportati: %s",
    "The command line tool %s could not be found" : "Lo strumento da riga di comando %s non è stato trovato",
    "The library %s is not available." : "La libreria %s non è disponibile.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Richiesta una versione della libreria %1$s maggiore di %2$s - versione disponibile %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Richiesta una versione della libreria %1$s minore di %2$s - versione disponibile %3$s.",
    "The following platforms are supported: %s" : "Le seguenti piattaforme sono supportate: %s",
    "Server version %s or higher is required." : "È richiesta la versione %s o successiva.",
    "Server version %s or lower is required." : "È richiesta la versione %s o precedente.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "L'account deve essere un amministratore, un amministratore secondario o disporre di diritti speciali per accedere a questa impostazione.",
    "Your current IP address doesn't allow you to perform admin actions" : "Il tuo attuale indirizzo IP non ti permette di eseguire azioni di amministrazione.",
    "Logged in account must be an admin or sub admin" : "L'account deve essere un amministratore o un amministratore secondario",
    "Logged in account must be an admin" : "L'account deve essere un amministratore",
    "Wiping of device %s has started" : "La cancellazione del dispositivo %s è iniziata",
    "Wiping of device »%s« has started" : "La cancellazione del dispositivo «%s» è iniziata",
    "»%s« started remote wipe" : "«%s» ha iniziato la cancellazione remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Il dispositivo o l'applicazione «%s» ha iniziato il processo di cancellazione remota. Riceverai un'altra email al termine del processo ",
    "Wiping of device %s has finished" : "La cancellazione del dispositivo %s è terminata",
    "Wiping of device »%s« has finished" : "La cancellazione del dispositivo «%s» è terminata",
    "»%s« finished remote wipe" : "«%s» ha terminato la cancellazione remota",
    "Device or application »%s« has finished the remote wipe process." : "Il dispositivo o l'applicazione «%s» ha terminato il processo di cancellazione remota.",
    "Remote wipe started" : "Cancellazione remota avviata",
    "A remote wipe was started on device %s" : "Una cancellazione remota è stata avviata sul dispositivo %s",
    "Remote wipe finished" : "Cancellazione remota terminata",
    "The remote wipe on %s has finished" : "La cancellazione remota su %s è terminata",
    "Authentication" : "Autenticazione",
    "Unknown filetype" : "Tipo di file sconosciuto",
    "Invalid image" : "Immagine non valida",
    "Avatar image is not square" : "L'immagine personale non è quadrata",
    "Files" : "File",
    "View profile" : "Vedi profilo",
    "same time" : "nello stesso momento",
    "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
    "_%nm_::_%nm_" : ["%nm","%nm","%nm"],
    "%s ahead" : "%s avanti",
    "%s behind" : "%s indietro",
    "Local time: %s" : "Ora locale: %s",
    "today" : "oggi",
    "tomorrow" : "domani",
    "yesterday" : "ieri",
    "_in %n day_::_in %n days_" : ["tra %n giorno","tra %n giorni","tra %n giorni"],
    "_%n day ago_::_%n days ago_" : ["%d giorno fa","%n giorni fa","%n giorni fa"],
    "next month" : "il prossimo mese",
    "last month" : "mese scorso",
    "_in %n month_::_in %n months_" : ["tra %n mese","tra %n mesi","tra %n mesi"],
    "_%n month ago_::_%n months ago_" : ["%n mese fa","%n mesi fa","%n mesi fa"],
    "next year" : "il prossimo anno",
    "last year" : "anno scorso",
    "_in %n year_::_in %n years_" : ["tra %n anno","tra %n anni","tra %n anni"],
    "_%n year ago_::_%n years ago_" : ["%n anno fa","%n anni fa","%n anni fa"],
    "_in %n hour_::_in %n hours_" : ["tra %n ora","tra %n ore","tra %n ore"],
    "_%n hour ago_::_%n hours ago_" : ["%n ora fa","%n ore fa","%n ore fa"],
    "_in %n minute_::_in %n minutes_" : ["tra %n minuto","tra %n minuti","tra %n minuti"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuto fa","%n minuti fa","%n minuti fa"],
    "in a few seconds" : "tra pochi secondi",
    "seconds ago" : "secondi fa",
    "Empty file" : "File vuoto",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Il modulo con ID: %s non esiste. Abilitalo nelle impostazioni delle applicazioni o contatta il tuo amministratore.",
    "No file conversion providers available" : "Nessun fornitore di conversione file disponibile",
    "File is too large to convert" : "Il file è troppo grande per essere convertito",
    "Destination does not match conversion extension" : "La destinazione non corrisponde all'estensione di conversione",
    "Could not convert file" : "Impossibile convertire file",
    "Destination does not exist" : "La destinazione non esiste",
    "Destination is not creatable" : "Impossibile creare la destinazione",
    "Dot files are not allowed" : "I file con un punto iniziale non sono consentiti",
    "%1$s (renamed)" : "%1$s (rinominato)",
    "renamed file" : "file rinominato",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" è un nome vietato per il file o la cartella.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" è un prefisso vietato per il file o la cartella.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" è vietato all'interno del nome di un file o cartella.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" è un formato file vietato.",
    "Filenames must not end with \"%1$s\"." : "I file non devono finire con \"%1$s\".",
    "Invalid parent path" : "Percorso genitore non valido.",
    "File already exists" : "Il file esiste già",
    "Invalid path" : "Percorso non valido",
    "Failed to create file from template" : "Impossibile creare un file dal modello",
    "Templates" : "Modelli",
    "Storage %s cannot be moved" : "Lo spazio %s non può essere spostato",
    "Moving a share (%s) into a shared folder is not allowed" : "Non è permesso sportare una condivisone (%s) dentro una cartella condivisa ",
    "Moving a storage (%s) into a shared folder is not allowed" : "Non è permesso sportare uno spazio (%s) dentro una cartella condivisa",
    "Moving a share (%s) into another share (%s) is not allowed" : "Non è permesso sportare una condivisione (%s) dentro un'altra condivisione (%s)",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Non è permesso sportare una condivisone (%s) dentro un altro spazio (%s)",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Non è permesso sportare spostare uno spazio (%s) dentro una condivsione (%s)",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Non è permesso sportare uno spazio (%s) dentro un altro spazio (%s)",
    "Path contains invalid segments" : "Il percorso contiene segmenti non validi",
    "Filename is a reserved word" : "Il nome del file è una parola riservata",
    "Filename contains at least one invalid character" : "Il nome del file contiene almeno un carattere non valido",
    "Filename is too long" : "Il nome del file è troppo lungo",
    "Empty filename is not allowed" : "Un nome di file vuoto non è consentito",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'applicazione \"%s\" non può essere installata poiché il file appinfo non può essere letto.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'applicazione \"%s\" non può essere installata perché non è compatibile con questa versione del server.",
    "__language_name__" : "Italiano",
    "This is an automatically sent email, please do not reply." : "Questo è un messaggio di posta inviato automaticamente, non rispondere.",
    "Help & privacy" : "Supporto & privacy",
    "Appearance and accessibility" : "Aspetto e accessibilità",
    "Apps" : "Applicazioni",
    "Personal settings" : "Impostazioni personali",
    "Administration settings" : "Impostazioni di amministrazione",
    "Settings" : "Impostazioni",
    "Log out" : "Esci",
    "Accounts" : "Account",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Guarda %s su Bluesky",
    "Email" : "Email",
    "Mail %s" : "Email a %s",
    "Fediverse" : "Fediverso",
    "View %s on the fediverse" : "Visualizza %s sul fediverso",
    "Phone" : "Telefono",
    "Call %s" : "Chiama %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Vedi %s su Twitter",
    "Website" : "Sito web",
    "Visit %s" : "Visita %s",
    "Address" : "Indirizzo",
    "Profile picture" : "Immagine di profilo",
    "About" : "Informazioni",
    "Display name" : "Nome visualizzato",
    "Headline" : "Titolo",
    "Organization" : "Organizzazione",
    "Role" : "Ruolo",
    "Pronouns" : "Pronomi",
    "Unknown account" : "Account sconosciuto",
    "Additional settings" : "Impostazioni aggiuntive",
    "Enter the database Login and name for %s" : "Inserisci il login e il nome per accedere al database per %s",
    "Enter the database Login for %s" : "Inserisci il login per accedere al database per %s",
    "Enter the database name for %s" : "Inserisci il nome del database per %s",
    "You cannot use dots in the database name %s" : "Non puoi usare punti nel nome del database %s",
    "MySQL Login and/or password not valid" : "Nome utente e/o password non corretta per MySQL",
    "You need to enter details of an existing account." : "Devi inserire i dettagli di un account esistente.",
    "Oracle connection could not be established" : "La connessione a Oracle non può essere stabilita",
    "Oracle Login and/or password not valid" : "Nome utente e/o password Oracle non validi",
    "PostgreSQL Login and/or password not valid" : "Nome utente e/o password non corretta per PostgreSQL",
    "macOS is not supported and %s will not work properly on this platform." : "macOS non è supportato e %s non funzionerà correttamente su questa piattaforma.",
    "For the best results, please consider using a GNU/Linux server instead." : "Per avere il risultato migliore, prendi in considerazione l'utilizzo di un server GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembra che questa istanza di %s sia in esecuzione in un ambiente PHP a 32 bit e che open_basedir sia stata configurata in php.ini. Ciò comporterà problemi con i file più grandi di 4 GB ed è altamente sconsigliato.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Rimuovi l'impostazione di open_basedir nel tuo php.ini o passa alla versione a 64 bit di PHP.",
    "Set an admin Login." : "Imposta un nome utente amminstratore",
    "Set an admin password." : "Imposta una password di amministrazione.",
    "Cannot create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Il motore di condivisione %s deve implementare l'interfaccia OCP\\Share_Backend",
    "Sharing backend %s not found" : "Motore di condivisione %s non trovato",
    "Sharing backend for %s not found" : "Motore di condivisione di %s non trovato",
    "%1$s shared %2$s with you" : "%1$s ha condiviso %2$s con te",
    "Open %s" : "Apri %s",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s ha condiviso %2$s con te e vuole aggiungere:",
    "%1$s shared %2$s with you and wants to add" : "%1$s ha condiviso %2$s con te e vuole aggiungere",
    "%s added a note to a file shared with you" : "%s ha aggiunto una nota a un file condiviso con te",
    "Passwords are enforced for link and mail shares" : "Le password sono obbligatorie per i link e le condivisioni di posta elettronica.",
    "Share recipient is not a valid user" : "Il destinatario della condivisione non è un utente valido",
    "Share recipient is not a valid group" : "Il destinatario della condivisione non è un gruppo valido",
    "Share recipient should be empty" : "Il destinatario della condivisione deve essere vuoto",
    "Share recipient should not be empty" : "Il destinatario della condivisione non deve essere vuoto",
    "Share recipient is not a valid circle" : "Il destinatario della condivisione non è un circolo valido",
    "Unknown share type" : "Tipo di condivisione sconosciuto",
    "Share initiator must be set" : "È necessario impostare l'iniziatore della condivisione",
    "Cannot share with yourself" : "Non puoi condividere con te stesso.",
    "Shared path must be set" : "È necessario impostare il percorso condiviso",
    "Shared path must be either a file or a folder" : "Il percorso condiviso deve essere un file o una cartella",
    "You cannot share your root folder" : "Non puoi condividere la tua cartella principale",
    "You are not allowed to share %s" : "Non ti è consentito condividere %s",
    "Valid permissions are required for sharing" : "Per la condivisione sono necessarie autorizzazioni valide",
    "File shares cannot have create or delete permissions" : "Le condivisioni di file non possono avere autorizzazioni di creazione o eliminazione.",
    "Cannot increase permissions of %s" : "Impossibile aumentare i permessi di %s",
    "Shares need at least read permissions" : "Le condivisioni hanno bisogno almeno del permesso di lettura",
    "Files cannot be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
    "Files cannot be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
    "Expiration date is in the past" : "La data di scadenza è nel passato",
    "Expiration date is enforced" : "La data di scadenza è obbligatoria",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossibile impostare la data di scadenza a più di %n giorni nel futuro","Impossibile impostare la data di scadenza a più di %n giorni nel futuro","Impossibile impostare la data di scadenza a più di %n giorni nel futuro"],
    "Sharing is only allowed with group members" : "La condivisione è consentita solo con i membri del gruppo",
    "Sharing %s failed, because this item is already shared with the account %s" : "La condivisione di %s non è riuscita, perché questo elemento è già condiviso con l'account %s",
    "Group sharing is now allowed" : "La condivisione con i gruppi non è permessa",
    "Sharing is only allowed within your own groups" : "La condivisione è permessa solo con i propri gruppi",
    "Path is already shared with this group" : "Il percorso è già condiviso con questi gruppi",
    "Link sharing is not allowed" : "La condivisione via link non è permessa",
    "Public upload is not allowed" : "Il caricamento pubblico non è permesso",
    "You cannot share a folder that contains other shares" : "Non puoi condividere una cartella che contiene altre condivisioni",
    "Sharing is disabled" : "La condivisione è disabilitata",
    "Sharing is disabled for you" : "La condivisione è disabilitata per te",
    "Cannot share with the share owner" : "Non puoi condividere con il proprietario della condivisione",
    "Share does not have a full ID" : "La condivisione non ha un ID completo",
    "Cannot change share type" : "Non puoi cambiare tipo di condivisione",
    "Can only update recipient on user shares" : "Puoi solamente aggiornare i destinatari di una condivisione",
    "Cannot enable sending the password by Talk with an empty password" : "Impossibile abilitare l'invio della password tramite Talk con una password vuota",
    "Cannot enable sending the password by Talk without setting a new password" : "Non è possibile abilitare l'invio della password tramite Talk senza impostare una nuova password.",
    "Cannot disable sending the password by Talk without setting a new password" : "Non è possibile disabilitare l'invio della password tramite Talk senza impostare una nuova password.",
    "Share provider does not support accepting" : "Il provider di condivisione non supporta l'accettazione",
    "Cannot change target of link share" : "Impossibile modificare la destinazione della condivisione del collegamento",
    "Invalid share recipient" : "Destinatario della condivisione non valido",
    "Group \"%s\" does not exist" : "Il gruppo \"%s\" non esiste",
    "The requested share does not exist anymore" : "La condivisione richiesta non esiste più",
    "The requested share comes from a disabled user" : "La condivisione richiesta proviene da un utente disabilitato",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "L'utente non è stato creato perché il limite è stato raggiunto. Controlla le notifiche per maggiori informazioni.",
    "Could not find category \"%s\"" : "Impossibile trovare la categoria \"%s\"",
    "Input text" : "Testo di input",
    "The input text" : "Il testo di input",
    "Sunday" : "Domenica",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Gio.",
    "Fri." : "Ven.",
    "Sat." : "Sab.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Gi",
    "Fr" : "Ve",
    "Sa" : "Sa",
    "January" : "Gennaio",
    "February" : "Febbraio",
    "March" : "Marzo",
    "April" : "Aprile",
    "May" : "Maggio",
    "June" : "Giugno",
    "July" : "Luglio",
    "August" : "Agosto",
    "September" : "Settembre",
    "October" : "Ottobre",
    "November" : "Novembre",
    "December" : "Dicembre",
    "Jan." : "Gen.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mag.",
    "Jun." : "Giu.",
    "Jul." : "Lug.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Ott.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "A valid password must be provided" : "Deve essere fornita una password valida",
    "The Login is already being used" : "Il Login è già utilizzato",
    "Could not create account" : "Impossibile creare l'account",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un Login: \"a-z\", \"A-Z\", \"0-9\", spazi e \"_.@-'\"",
    "A valid Login must be provided" : "Deve essere fornito un Login valido",
    "Login contains whitespace at the beginning or at the end" : "Il Login contiene spazi all'inizio o alla fine",
    "Login must not consist of dots only" : "Il Login non può consistere di soli punti",
    "Username is too long" : "Il nome utente è troppo lungo",
    "Login is invalid because files already exist for this user" : "Il Login non è valido poiché esistono già file per questo utente",
    "Account disabled" : "Account disabilitato",
    "Login canceled by app" : "Accesso annullato dall'applicazione",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'applicazione \"%1$s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %2$s",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Application is not enabled" : "L'applicazione non è abilitata",
    "Authentication error" : "Errore di autenticazione",
    "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nessun driver di database (sqlite, mysql o postgresql) installato",
    "Cannot write into \"config\" directory." : "Impossibile scrivere nella cartella \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella config. Vedi %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true. Vedi %s",
    "Cannot create \"data\" directory." : "Impossibile creare la cartella \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella radice. Vedi %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "I permessi possono essere corretti di solito fornendo al server web accesso in scrittura alla cartella radice. Vedi %s.",
    "Your data directory is not writable." : "La cartella dei dati non è scrivibile.",
    "Setting locale to %s failed." : "L'impostazione della lingua in %s è fallita.",
    "Please install one of these locales on your system and restart your web server." : "Installa una di queste lingue sul sistema e riavvia il server web.",
    "PHP module %s not installed." : "Il modulo PHP %s non è installato.",
    "Please ask your server administrator to install the module." : "Chiedi all'amministratore del tuo server di installare il modulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "L'impostazione \"%s\" di PHP non è configurata a \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Per eseguire nuovamente Nextcloud, modificare questa impostazione nel file php.ini",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Sono stati installati moduli PHP, ma sono elencati ancora come mancanti?",
    "Please ask your server administrator to restart the web server." : "Chiedi all'amministratore di riavviare il server web.",
    "The required %s config variable is not configured in the config.php file." : "La variabile %s necessaria non è configurata nel file config.php .",
    "Please ask your server administrator to check the Nextcloud configuration." : "Chiedi all'amministratore del server di controllare la configurazione di Nextcloud.",
    "Your data directory is readable by other people." : "La cartella dei dati è leggibile dalle altre persone.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dalle altre persone.",
    "Your data directory must be an absolute path." : "La cartella dei dati deve essere un percorso assoluto.",
    "Check the value of \"datadirectory\" in your configuration." : "Controlla il valore di \"datadirectory\" nella tua configurazione.",
    "Your data directory is invalid." : "La cartella dei dati non è valida.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Assicurati che ci sia un file \"%1$s\" nella radice della cartella data. Dovrebbe avere il contenuto: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Azione \"%s\" non supportata o implementata.",
    "Authentication failed, wrong token or provider ID given" : "Autenticazione non riuscita, token o ID fornitore errato ",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametri mancanti per completare la richiesta. Parametri mancanti: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" già utilizzato dal fornitore della federazione cloud \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Il fornitore della federazione cloud con ID: \"%s\" non esiste.",
    "Could not obtain lock type %d on \"%s\"." : "Impossibile ottenere il blocco di tipo %d su \"%s\".",
    "Storage unauthorized. %s" : "Archiviazione non autorizzata. %s",
    "Storage incomplete configuration. %s" : "Configurazione dell'archiviazione incompleta.%s",
    "Storage connection error. %s" : "Errore di connessione all'archiviazione. %s",
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage connection timeout. %s" : "Timeout di connessione all'archiviazione. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Per consentire l'esecuzione di questo controllo, è necessario assicurarsi che il server Web sia in grado di connettersi a se stesso. Pertanto, deve essere in grado di risolvere e connettersi ad almeno uno dei suoi `trusted_domains` o a `overwrite.cli.url`. Questo errore può essere causato da una mancata corrispondenza DNS lato server o da una regola firewall in uscita.",
    "Analyze images" : "Analizzare le immagini",
    "Ask a question about the given images." : "Poni una domanda sulle immagini fornite.",
    "Images" : "Immagini",
    "Images to ask a question about" : "Immagini su cui porre una domanda",
    "Question" : "Domanda",
    "What to ask about the images." : "Cosa chiedere riguardo le immagini.",
    "Generated response" : "Risposta generata",
    "The answer to the question" : "La risposta alla domanda",
    "Audio chat" : "Chat audio",
    "Voice chat with the assistant" : "Chat audio con l'assistente",
    "System prompt" : "Prompt di sistema",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Definisci le regole e le ipotesi che l'assistente dovrebbe seguire durante la conversazione.",
    "Chat voice message" : "Messaggio vocale di chat",
    "Describe a task that you want the assistant to do or ask a question." : "Descrivi un compito che desideri che l'assistente svolga o poni una domanda.",
    "Chat history" : "Cronologia chat",
    "The history of chat messages before the current message, starting with a message by the user." : "La cronologia dei messaggi di chat precedenti al messaggio corrente, a partire da un messaggio dell'utente.",
    "Input transcript" : "Trascrizione dell'input",
    "Transcription of the audio input" : "Trascrizione dell'input audio",
    "Response voice message" : "Messaggio vocale di risposta",
    "The generated voice response as part of the conversation" : "La risposta vocale generata come parte della conversazione",
    "Output transcript" : "Trascrizione dell'output",
    "Transcription of the audio output" : "Trascrizione dell'output audio",
    "Transcribe audio" : "Trascrivi audio",
    "Transcribe the things said in an audio" : "Trascrivi le cose che dico in un audio",
    "Audio input" : "Input audio",
    "The audio to transcribe" : "L'audio da trascrivere",
    "Transcription" : "Trascrizione",
    "The transcribed text" : "Il testo trascritto",
    "Chat by voice with an agent" : "Chatta con un agente tramite voce",
    "Describe a task that you want the agent to do or ask a question." : "Descrivi un'attività che desideri che l'agente svolga o poni una domanda.",
    "Confirmation" : "Conferma",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Se confermare le azioni richieste in precedenza: 0 per rifiutare e 1 per confermare.",
    "Conversation token" : "Token della conversazione",
    "A token representing the conversation." : "Un token che rappresenta la conversazione.",
    "The new conversation token" : "Il nuovo token della conversazione",
    "Send this along with the next interaction." : "Invialo insieme alla prossima interazione.",
    "Requested actions by the agent" : "Azioni richieste dall'agente",
    "Actions that the agent would like to carry out in JSON format." : "Azioni che l'agente desidera eseguire in formato JSON.",
    "Chat with an agent" : "Chatta con un agente",
    "Chat message" : "Messaggio di chat",
    "A chat message to send to the agent." : "Un messaggio di chat da inviare all'agente.",
    "The response from the chat model." : "La risposta del modello di chat.",
    "Context write" : "Scrittura contestuale",
    "Writes text in a given style based on the provided source material." : "Scrive un testo in uno stile prestabilito basandosi sul materiale di partenza fornito.",
    "Writing style" : "Stile di scrittura",
    "Demonstrate a writing style that you would like to immitate" : "Dimostra uno stile di scrittura che vorresti imitare.",
    "Source material" : "Materiale di partenza",
    "The content that would like to be rewritten in the new writing style" : "Il contenuto che vorresti fosse riscritto nel nuovo stile di scrittura",
    "Generated text" : "Testo generato",
    "The generated text with content from the source material in the given style" : "Il testo generato con il contenuto del materiale di origine nello stile specificato",
    "Emoji generator" : "Generatore di emoji",
    "Takes text and generates a representative emoji for it." : "Prende il testo e genera un'emoji rappresentativa.",
    "The text to generate an emoji for" : "Il testo per cui generare un'emoji",
    "Generated emoji" : "Emoji generata",
    "The generated emoji based on the input text" : "L'emoji generata in base al testo inserito",
    "Optical character recognition" : "Riconoscimento ottico dei caratteri",
    "Extract text from files like images or PDFs" : "Estrai testo da file come immagini o PDF",
    "Input files" : "File in ingresso",
    "The files to extract text from" : "Scegli in file da cui estrarre il testo",
    "Output texts" : "Testo in uscita",
    "The texts that were extracted from the files" : "Il testo che è stato estratto dai file",
    "Generate image" : "Genera immagine",
    "Generate an image from a text prompt" : "Genera un'immagine da un prompt di testo",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Descrivi l'immagine che desideri generare",
    "Number of images" : "Numero di immagini",
    "How many images to generate" : "Quante immagini generare",
    "Output images" : "Immagini generate",
    "The generated images" : "Le immagini generate",
    "Generate speech" : "Generare discorso",
    "Generate speech from a transcript" : "Generare un discorso da una trascrizione",
    "Write transcript that you want the assistant to generate speech from" : "Scrivi la trascrizione da cui vuoi che l'assistente generi il discorso",
    "Output speech" : "Discorso di output",
    "The generated speech" : "Il discorso generato",
    "Free text to text prompt" : "Prompt da testo libero a testo",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Esegue un prompt arbitrario attraverso un modello linguistico che restituisce una risposta.",
    "Describe a task that you want the assistant to do or ask a question" : "Descrivi un compito che desideri che l'assistente svolga o poni una domanda.",
    "Generated reply" : "Risposta generata",
    "The generated text from the assistant" : "Il testo generato dall'assistente",
    "Change Tone" : "Cambia Tono",
    "Change the tone of a piece of text." : "Cambia il tono di un brano di testo.",
    "Write a text that you want the assistant to rewrite in another tone." : "Scrivi un testo che vuoi che l'assistente riscriva con un tono diverso.",
    "Desired tone" : "Tono desiderato",
    "In which tone should your text be rewritten?" : "Con quale tono dovresti riscrivere il tuo testo?",
    "The rewritten text in the desired tone, written by the assistant:" : "Il testo riscritto nel tono desiderato, scritto dall'assistente:",
    "Chat" : "Chat",
    "Chat with the assistant" : "Chatta con l'assistente",
    "The history of chat messages before the current message, starting with a message by the user" : "La cronologia dei messaggi di chat precedenti al messaggio corrente, a partire da un messaggio dell'utente",
    "Response message" : "Messaggio di risposta",
    "The generated response as part of the conversation" : "La risposta generata come parte della conversazione",
    "Chat with tools" : "Chat con strumenti",
    "Chat with the language model with tool calling support." : "Chatta con il modello di linguaggio con supporto per la chiamata degli strumenti.",
    "Tool message" : "Messaggio dello strumento",
    "The result of tool calls in the last interaction" : "Il risultato delle chiamate agli strumenti nell'ultima interazione",
    "Available tools" : "Strumenti disponibili",
    "The available tools in JSON format" : "Gli strumenti disponibili in formato JSON",
    "The response from the chat model" : "La risposta del modello di chat",
    "Tool calls" : "Chiamate degli strumenti",
    "Tools call instructions from the model in JSON format" : "Gli strumenti chiamano le istruzioni dal modello in formato JSON",
    "Formalize text" : "Formalizza il testo",
    "Takes a text and makes it sound more formal" : "Prende un testo e lo rende più formale",
    "Write a text that you want the assistant to formalize" : "Scrivi un testo che desideri che l'assistente formalizzi",
    "Formalized text" : "Testo formalizzato",
    "The formalized text" : "Il testo formalizzato",
    "Generate a headline" : "Genera un titolo",
    "Generates a possible headline for a text." : "Genera un possibile titolo per un testo.",
    "Original text" : "Testo originale",
    "The original text to generate a headline for" : "Il testo originale per cui generare un titolo",
    "The generated headline" : "Il titolo generato",
    "Proofread" : "Correzione di bozze",
    "Proofreads a text and lists corrections" : "Correggere un testo ed elencare le correzioni",
    "Text" : "Testo",
    "The text to proofread" : "Il testo da correggere",
    "Corrections" : "Correzioni",
    "The corrections that should be made in your text" : "Le correzioni da apportare al tuo testo",
    "Reformulate text" : "Riformula il testo",
    "Takes a text and reformulates it" : "Prende un testo e lo riformula",
    "Write a text that you want the assistant to reformulate" : "Scrivi un testo che desideri che l'assistente riformuli.",
    "Reformulated text" : "Testo riformulato",
    "The reformulated text, written by the assistant" : "Il testo riformulato, scritto dall'assistente",
    "Simplify text" : "Semplifica il testo",
    "Takes a text and simplifies it" : "Prende un testo e lo semplifica",
    "Write a text that you want the assistant to simplify" : "Scrivi un testo che desideri venga semplificato dall'assistente.",
    "Simplified text" : "Testo semplificato",
    "The simplified text" : "Il testo semplificato",
    "Summarize" : "Riassumi",
    "Summarizes a text" : "Riassumi un testo",
    "The original text to summarize" : "Il testo originale da riassumere",
    "Summary" : "Riepilogo",
    "The generated summary" : "Il riassunto generato",
    "Extract topics" : "Estrai argomenti",
    "Extracts topics from a text and outputs them separated by commas" : "Estrae argomenti da un testo e li riporta separati da virgole.",
    "The original text to extract topics from" : "Il testo originale da cui estrarre gli argomenti",
    "Topics" : "Argomenti",
    "The list of extracted topics" : "La lista degli argomenti estratti",
    "Translate" : "Traduci",
    "Translate text from one language to another" : "Tradurre il testo da una lingua all'altra",
    "Origin text" : "Testo d'origine",
    "The text to translate" : "Il testo da tradurre",
    "Origin language" : "Lingua d'origine",
    "The language of the origin text" : "La lingua del testo d'origine",
    "Target language" : "Lingua di destinazione",
    "The desired language to translate the origin text in" : "La lingua in cui si desidera tradurre il testo originale",
    "Result" : "Risultato",
    "The translated text" : "Il testo tradotto",
    "Free prompt" : "Prompt libero",
    "Runs an arbitrary prompt through the language model." : "Esegue un prompt arbitrario attraverso il modello di lingua.",
    "Generate headline" : "Genera titolo",
    "Summarizes text by reducing its length without losing key information." : "Riassume il testo riducendone la lunghezza senza perdere le informazioni chiave.",
    "Extracts topics from a text and outputs them separated by commas." : "Estrae gli argomenti da un testo e li elenca separati da virgole.",
    "Organisation" : "Organizzazione",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X non è supportato e %s non funzionerà correttamente su questa piattaforma. Utilizzarlo a proprio rischio!",
    "Login is too long" : "Il Login è troppo lungo",
    "Cannot write into \"apps\" directory." : "Impossibile scrivere nella cartella \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella delle applicazioni o disattivando il negozio delle applicazioni nel file di configurazione.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> è impostato a <code>%s</code> invece del valore previsto <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Per correggere questo problema, imposta <code>mbstring.func_overload</code> a <code>0</code> nel tuo php.ini."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
